@@ -34,7 +34,7 @@ from functools import partial
 from itertools import chain
 
 import portage
-from portage import _encodings, _unicode_decode, _unicode_encode
+from portage import _encodings, _unicode_encode
 
 from gentoolkit import pprinter as pp
 from gentoolkit import errors
@@ -197,7 +197,7 @@ class ChangeLog(object):
 
 		result = []
 		partial_entries = []
-		with open(_unicode_encode(self.changelog_path, 
+		with open(_unicode_encode(self.changelog_path,
 			encoding=_encodings['fs'], errors="replace"),
 			encoding=_encodings['content']) as log:
 			for line in log:
@@ -257,7 +257,7 @@ class FileOwner(object):
 			raise errors.GentoolkitInvalidRegex(err)
 
 		use_match = False
-		if ((self.is_regex or query_re_string.startswith('^\/'))
+		if ((self.is_regex or query_re_string.startswith(r'^\/'))
 			and '|' not in query_re_string ):
 			# If we were passed a regex or a single path starting with root,
 			# we can use re.match, else use re.search.
@@ -350,7 +350,7 @@ class FileOwner(object):
 		else:
 			result = []
 			# Trim trailing and multiple slashes from queries
-			slashes = re.compile('/+')
+			slashes = re.compile(r'/+')
 			queries = self.expand_abspaths(queries)
 			queries = self.extend_realpaths(queries)
 			for query in queries:
@@ -414,8 +414,6 @@ def get_cpvs(predicate=None, include_installed=True):
 				yield cpv
 
 
-# pylint thinks this is a global variable
-# pylint: disable-msg=C0103
 get_uninstalled_cpvs = partial(get_cpvs, include_installed=False)
 
 
